===============
Extension Hooks
===============

.. If you add to this list, make sure to also add to extending/index.rst.

.. toctree::
   :maxdepth: 1

   account-page-forms-hook
   account-pages-hook
   action-hooks
   admin-widget-hook
   api-extra-data-access-hook
   auth-backend-hook
   avatar-service-hook
   comment-detail-display-hook
   dashboard-columns-hook
   dashboard-sidebar-items-hook
   datagrid-columns-hook
   email-hook
   file-attachment-thumbnail-hook
   hosting-service-hook
   integration-hook
   navigation-bar-hook
   review-request-approval-hook
   review-request-fields-hook
   review-request-fieldsets-hook
   review-ui-hook
   signal-hook
   template-hook
   url-hook
   user-infobox-hook
   user-page-sidebar-items-hook
   webapi-capabilities-hook
